summaryrefslogtreecommitdiffstats
path: root/parts/bookmarks/bookmarks_part.h
diff options
context:
space:
mode:
Diffstat (limited to 'parts/bookmarks/bookmarks_part.h')
-rw-r--r--parts/bookmarks/bookmarks_part.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/parts/bookmarks/bookmarks_part.h b/parts/bookmarks/bookmarks_part.h
index f51603d7..b8015f54 100644
--- a/parts/bookmarks/bookmarks_part.h
+++ b/parts/bookmarks/bookmarks_part.h
@@ -10,8 +10,8 @@
***************************************************************************/
-#ifndef __KDEVPART_BOOKMARKS_H__
-#define __KDEVPART_BOOKMARKS_H__
+#ifndef __TDEVPART_BOOKMARKS_H__
+#define __TDEVPART_BOOKMARKS_H__
#include <tqguardedptr.h>
@@ -22,7 +22,7 @@
#include <tdeparts/part.h>
#include <kurl.h>
-#include <kdevplugin.h>
+#include <tdevplugin.h>
class TQTimer;
class KDialogBase;
@@ -38,7 +38,7 @@ struct EditorData
class BookmarksWidget;
class TQDomElement;
-class BookmarksPart : public KDevPlugin
+class BookmarksPart : public TDevPlugin
{
Q_OBJECT
@@ -48,7 +48,7 @@ public:
BookmarksPart(TQObject *parent, const char *name, const TQStringList &);
~BookmarksPart();
// reimplemented from KDevPlugin
void restorePartialProjectSession( const TQDomElement * el );
void savePartialProjectSession( TQDomElement * el );
@@ -48,7 +48,7 @@ public:
BookmarksPart(TQObject *parent, const char *name, const TQStringList &);
~BookmarksPart();
- // reimplemented from KDevPlugin
+ // reimplemented from TDevPlugin
void restorePartialProjectSession( const TQDomElement * el );
void savePartialProjectSession( TQDomElement * el );